concat_bus

Function concat_bus 

pub fn concat_bus(filenames: Vec<String>, outfile: &str)
Concatenate several busfiles

Assumes that each file is sorted If a record (CB/UMI/EC) is found in more than one busfile, its count is aggregated (also if the same CB/UMI/EC is present in the same file)