Module bustools_cli::correct

source ·
Code for bustools correct to correct sequencing errors in Cell Barcodes using a whitelist

Pretty straight forward: Operates via a BKTree, which allows for quick “approximate” matching

Functions

  • Corrects observed barcodes in the busfile using a whitelist of barcodes and writes the results to disk