Module bustools_cli::count2
source · Expand description
This turns a busfolder into a count matrix, slightly different strategy than crate::count. Not sure which is fsater
Functions
- count the busfile in the given folder, see crate::count::count
- Slightly different strategy as count.rs: