Module bustools_cli::sort
source · Expand description
bustools sort code. Sorts busfiles by CB/UMI/EC
Merging records
Note that this not only sorts records according to CB/UMI/EC, but also merges records with the same CB/UMI/EC/FLAG (adding up their counts)
Functions
- Sort a busfile on disk (i.e. without loading the entire thing into memory) Works via
mergesort: